aboutsummaryrefslogtreecommitdiff
path: root/mod/messageboard/actions/delete.php
diff options
context:
space:
mode:
authorcash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-05-12 23:31:00 +0000
committercash <cash@36083f99-b078-4883-b0ff-0f9b5a30f544>2010-05-12 23:31:00 +0000
commit4ae064871ba9dca9f03e095671db48815632d070 (patch)
treeccccacdac0f608e2d262d1d3a8916408c033f132 /mod/messageboard/actions/delete.php
parent8618288ed51942c814f45c67354b14eec43c2422 (diff)
downloadelgg-4ae064871ba9dca9f03e095671db48815632d070.tar.gz
elgg-4ae064871ba9dca9f03e095671db48815632d070.tar.bz2
merging messageboard cleanup from 1.7 branch [5908],[5909],[5917]
git-svn-id: http://code.elgg.org/elgg/trunk@6019 36083f99-b078-4883-b0ff-0f9b5a30f544
Diffstat (limited to 'mod/messageboard/actions/delete.php')
-rw-r--r--mod/messageboard/actions/delete.php75
1 files changed, 36 insertions, 39 deletions
diff --git a/mod/messageboard/actions/delete.php b/mod/messageboard/actions/delete.php
index 9c17f1fcd..c903a0d20 100644
--- a/mod/messageboard/actions/delete.php
+++ b/mod/messageboard/actions/delete.php
@@ -1,44 +1,41 @@
<?php
- /**
- * Elgg Message board: delete message action
- *
- * @package ElggMessageBoard
- * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
- * @author Curverider Ltd <info@elgg.com>
- * @copyright Curverider Ltd 2008-2010
- * @link http://elgg.org/
- */
+/**
+ * Elgg Message board: delete message action
+ *
+ * @package ElggMessageBoard
+ * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
+ * @author Curverider Ltd <info@elgg.com>
+ * @copyright Curverider Ltd 2008-2010
+ * @link http://elgg.org/
+ */
- // Ensure we're logged in
- if (!isloggedin()) forward();
-
- // Make sure we can get the comment in question
- $annotation_id = (int) get_input('annotation_id');
-
- //make sure that there is a message on the message board matching the passed id
- if ($message = get_annotation($annotation_id)) {
-
- //grab the user or group entity
- $entity = get_entity($message->entity_guid);
-
- //check to make sure the current user can actually edit the message board
- if ($message->canEdit()) {
- //delete the comment
- $message->delete();
- //display message
- system_message(elgg_echo("messageboard:deleted"));
- //generate the url to forward to
- $url = "pg/messageboard/" . $entity->username;
- //forward the user back to their message board
- forward($url);
- }
-
- } else {
- $url = "";
- system_message(elgg_echo("messageboard:notdeleted"));
- }
-
+// Make sure we can get the comment in question
+$annotation_id = (int) get_input('annotation_id');
+
+//make sure that there is a message on the message board matching the passed id
+if ($message = get_annotation($annotation_id)) {
+
+ //grab the user or group entity
+ $entity = get_entity($message->entity_guid);
+
+ //check to make sure the current user can actually edit the message board
+ if ($message->canEdit()) {
+ //delete the comment
+ $message->delete();
+ // delete river entry
+ remove_from_river_by_annotation($annotation_id);
+ //display message
+ system_message(elgg_echo("messageboard:deleted"));
+ //generate the url to forward to
+ $url = "pg/messageboard/" . $entity->username;
+ //forward the user back to their message board
forward($url);
+ }
+
+} else {
+ $url = "";
+ system_message(elgg_echo("messageboard:notdeleted"));
+}
-?> \ No newline at end of file
+forward($url);